@@ -3,11 +3,12 @@
 # Purpose: all-in-one control centre for IceWM in antiX
 # Authors: OU812 and minor modifications by anticapitalista
 # Latest Change: 24 October 2013 by anticapitalista. Function for ICONS. New look.
+# Latest Change: 16 October 2018 by anticapitalista. Use set gtk icons
 
 TEXTDOMAINDIR=/usr/share/locale
 TEXTDOMAIN=icewmcc.sh
 # Options
-ICONS=/usr/share/icons/antix-faenza
+#ICONS=/usr/share/icons/antiX
 
 Taskbar=$"Taskbar" Applets=$"Applets" Workspaces=$"Workspaces" Windows=$"Windows"
 
@@ -24,7 +25,7 @@ export IceWMCC=$(cat <<End_of_Text
 	  <vbox>
                 <hbox>
 		  <button>
-		  <input file>"$ICONS/preferences-desktop-wallpaper.png"</input>
+		  <input file icon="preferences-desktop-wallpaper"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccshtb.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -33,7 +34,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox>
                  <hbox>
 		  <button>
-		  <input file>"$ICONS/computer.png"</input>
+		  <input file icon="computer"></input>
 		  <action>/usr/local/bin/icewmcc/icewmcctbpos.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -42,7 +43,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox>
 		<hbox>
 		  <button>
-		  <input file>"$ICONS/gnome-settings-default-applications.png"</input>
+		  <input file icon="gnome-settings-default-applications"></input>
 		  <action>/usr/local/bin/icewmcc/icewmcctbheight.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -60,7 +61,7 @@ export IceWMCC=$(cat <<End_of_Text
 	  <vbox>
 		<hbox>
 		  <button>
-		  <input file>"$ICONS/utilities-system-monitor.png"</input>
+		  <input file icon="utilities-system-monitor"></input>
 		  <action>/usr/local/bin/icewmcc/icewmcccpumon.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -69,7 +70,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox>
                 <hbox>
 		  <button>
-		  <input file>"$ICONS/network-assistant.png"</input>
+		  <input file icon="gnome-session"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccnetmon.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -78,7 +79,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox>
 		<hbox>
 		  <button>
-		  <input file>"$ICONS/mail.png"</input>
+		  <input file icon="mail"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccmail.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -96,7 +97,7 @@ export IceWMCC=$(cat <<End_of_Text
 	  <vbox>
 		<hbox>
 		  <button>
-		  <input file>"$ICONS/workspace-switcher.png"</input>
+		  <input file icon="printer"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccshowwkspaces.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -105,7 +106,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox>
                 <hbox>
 		  <button>
-		  <input file>"$ICONS/video-display.png"</input>
+		  <input file icon="video-display"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccwkspaces.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -114,7 +115,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox>
 		<hbox>
 		  <button>
-		  <input file>"$ICONS/preferences-desktop-theme.png"</input>
+		  <input file icon="preferences-desktop-theme"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccwinlist.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -132,7 +133,7 @@ export IceWMCC=$(cat <<End_of_Text
 	  <vbox>
                  <hbox>
 		  <button>
-		  <input file>"$ICONS/cs-desktop-effects.png"</input>
+		  <input file icon="cs-desktop-effects"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccmovestat.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -141,7 +142,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox> 
                 <hbox>
 		  <button>
-		  <input file>"$ICONS/computer.png"</input>
+		  <input file icon="computer"></input>
 		  <action>/usr/local/bin/icewmcc/icewmccopmove.sh &</action>
 		  </button>
 		  <text use-markup="true" width-chars="25">
@@ -150,7 +151,7 @@ export IceWMCC=$(cat <<End_of_Text
 		</hbox>
                 <hbox>
                   <button>
-                  <input file>"$ICONS/gparted.png"</input>
+                  <input file icon="gparted"></input>
                   <action>/usr/local/bin/icewmcc/icewmccopresize.sh &</action>
                   </button>
                   <text use-markup="true" width-chars="25">
@@ -165,7 +166,7 @@ export IceWMCC=$(cat <<End_of_Text
   <hbox>
 	<button>
 	<label>"Close"</label>
-	<input file icon="dialog-no"></input>
+	<input file icon="exit"></input>
 	<action>EXIT:close</action>
 	</button>
   </hbox>
